@@ -1,5 +1,5 @@
 # sql/crud.py
-# Copyright (C) 2005-2016 the SQLAlchemy authors and contributors
+# Copyright (C) 2005-2018 the SQLAlchemy authors and contributors
 # <see AUTHORS file>
 #
 # This module is part of SQLAlchemy and is released under
@@ -317,7 +317,7 @@ def _append_param_parameter(
             compiler, c, value, required=value is REQUIRED,
             name=_col_bind_name(c)
             if not stmt._has_multi_parameters
-            else "%s_0" % _col_bind_name(c),
+            else "%s_m0" % _col_bind_name(c),
             **kw
         )
     else:
@@ -395,8 +395,11 @@ def _create_update_prefetch_bind_param(compiler, c, process=True, name=None):
 
 
 class _multiparam_column(elements.ColumnElement):
+    _is_multiparam_column = True
+
     def __init__(self, original, index):
-        self.key = "%s_%d" % (original.key, index + 1)
+        self.index = index
+        self.key = "%s_m%d" % (original.key, index + 1)
         self.original = original
         self.default = original.default
         self.type = original.type
@@ -505,7 +508,7 @@ def _append_param_insert_select_hasdefault(
             (not c.default.optional or
              not compiler.dialect.sequences_optional):
             proc = c.default
-            values.append((c, proc))
+            values.append((c, proc.next_value()))
     elif c.default.is_clause_element:
         proc = c.default.arg.self_group()
         values.append((c, proc))
@@ -597,23 +600,28 @@ def _extend_values_for_multiparams(compiler, stmt, values, kw):
     values_0 = values
     values = [values]
 
-    values.extend(
-        [
-            (
-                c,
-                (_create_bind_param(
-                    compiler, c, row[c.key],
-                    name="%s_%d" % (c.key, i + 1)
-                ) if elements._is_literal(row[c.key])
-                    else compiler.process(
-                        row[c.key].self_group(), **kw))
-                if c.key in row else
-                _process_multiparam_default_bind(compiler, stmt, c, i, kw)
-            )
-            for (c, param) in values_0
-        ]
-        for i, row in enumerate(stmt.parameters[1:])
-    )
+    for i, row in enumerate(stmt.parameters[1:]):
+        extension = []
+        for (col, param) in values_0:
+            if col in row or col.key in row:
+                key = col if col in row else col.key
+
+                if elements._is_literal(row[key]):
+                    new_param = _create_bind_param(
+                        compiler, col, row[key],
+                        name="%s_m%d" % (col.key, i + 1), **kw
+                    )
+                else:
+                    new_param = compiler.process(row[key].self_group(), **kw)
+            else:
+                new_param = _process_multiparam_default_bind(
+                    compiler, stmt, col, i, kw
+                )
+
+            extension.append((col, new_param))
+
+        values.append(extension)
+
     return values
 
 
@@ -681,7 +689,7 @@ def _warn_pk_with_no_anticipated_value(c):
         "Primary key columns typically may not store NULL."
         %
         (c.table.fullname, c.name, c.table.fullname))
-    if len(c.table.primary_key.columns) > 1:
+    if len(c.table.primary_key) > 1:
         msg += (
             " Note that as of SQLAlchemy 1.1, 'autoincrement=True' must be "
             "indicated explicitly for composite (e.g. multicolumn) primary "
